@@ -1,4 +1,3 @@
-
 def import_sphinx():
     """
     sphinx is an optional extra, so only load it when necessary
@@ -9,8 +8,8 @@ def import_sphinx():
         raise ImportError(
             "Sphinx is not installed. "
             "Please install ipypublish with the sphinx extras: "
-            ">> pip install ipypublish[sphinx]")
-    if not sphinx.__version__ >= '1.6':
-        # This is required for sphinx.ext.imgconverter
-        raise ImportError("Sphinx version must be >= 1.6")
+            ">> pip install ipypublish[sphinx]"
+        )
+    if not sphinx.__version__ >= "1.8":
+        raise ImportError("Sphinx version must be >= 1.8")
     return sphinx
