@@ -58,16 +58,15 @@ logger = logging.getLogger(__name__)
 
 @pytest.fixture(autouse=True)
 def dont_open_webbrowser(monkeypatch):
-
     def nullfunc(*arg, **kwrgs):
         pass
 
-    monkeypatch.setattr('webbrowser.open', nullfunc)
+    monkeypatch.setattr("webbrowser.open", nullfunc)
 
 
 @pytest.fixture
 def external_export_plugin():
-    return pathlib.Path(os.path.join(TEST_FILES_DIR, 'example_new_plugin.json'))
+    return pathlib.Path(os.path.join(TEST_FILES_DIR, "example_new_plugin.json"))
 
 
 @pytest.fixture
@@ -86,10 +85,10 @@ def ipynb_params(request):
 
     # ##### process pytest.mark.ipynb
 
-    if hasattr(request.node, 'iter_markers'):  # pytest-3.6.0 or newer
-        markers = request.node.iter_markers('ipynb')
+    if hasattr(request.node, "iter_markers"):  # pytest-3.6.0 or newer
+        markers = request.node.iter_markers("ipynb")
     else:
-        markers = request.node.get_marker('ipynb')
+        markers = request.node.get_marker("ipynb")
     pargs = {}
     kwargs = {}
 
@@ -102,23 +101,26 @@ def ipynb_params(request):
 
     args = [pargs[i] for i in sorted(pargs.keys())]
 
-    return namedtuple('ipynb_params', 'args,kwargs')(args, kwargs)  # type: ignore
+    return namedtuple("ipynb_params", "args,kwargs")(args, kwargs)  # type: ignore
 
 
-@pytest.fixture(scope='function')
+@pytest.fixture(scope="function")
 def ipynb_app(temp_folder, ipynb_params):
 
     args, kwargs = ipynb_params
     if len(args) <= 0:
-        raise ValueError('a subfolder must be supplied as the first argument to ' '@pytest.mark.ipynb')
+        raise ValueError(
+            "a subfolder must be supplied as the first argument to "
+            "@pytest.mark.ipynb"
+        )
 
     subfolder = args[0]  # 'ipynb_with_glossary'
-    input_file = kwargs.get('main_file', 'main.ipynb')
-    test_files_dir = kwargs.get('root', TEST_FILES_DIR)
-    source_folder = kwargs.get('source', 'source')
-    convert_folder = kwargs.get('converted', 'converted')
-    expected_folder = kwargs.get('expected', 'expected')
-    use_temp = kwargs.get('out_to_temp', True)
+    input_file = kwargs.get("main_file", "main.ipynb")
+    test_files_dir = kwargs.get("root", TEST_FILES_DIR)
+    source_folder = kwargs.get("source", "source")
+    convert_folder = kwargs.get("converted", "converted")
+    expected_folder = kwargs.get("expected", "expected")
+    use_temp = kwargs.get("out_to_temp", True)
 
     source_folder_path = os.path.join(test_files_dir, subfolder, source_folder)
     expected_folder_path = os.path.join(test_files_dir, subfolder, expected_folder)
@@ -131,16 +133,10 @@ def ipynb_app(temp_folder, ipynb_params):
     else:
         converted_path = os.path.join(test_files_dir, subfolder, convert_folder)
 
-    yield IpyTestApp(
-        temp_source_path,
-        input_file,
-        converted_path,
-        expected_folder_path,
-    )
+    yield IpyTestApp(temp_source_path, input_file, converted_path, expected_folder_path)
 
 
 class IpyTestApp(object):
-
     def __init__(self, src_path, input_file, converted_path, expected_folder_path):
         self._src_folder_path = src_path
         self._converted_folder_path = converted_path
@@ -173,28 +169,32 @@ class IpyTestApp(object):
     def run(self, ipub_config=None):
         if ipub_config is None:
             ipub_config = {}
-        ipub_config['outpath'] = str(self.converted_path)
-        app = IpyPubMain(config={'IpyPubMain': ipub_config})
-        self._output_data = app(self.input_file if self.input_file is not None else self.source_path)
+        ipub_config["outpath"] = str(self.converted_path)
+        app = IpyPubMain(config={"IpyPubMain": ipub_config})
+        self._output_data = app(
+            self.input_file if self.input_file is not None else self.source_path
+        )
 
     @property
     def output_data(self):
         if self._output_data is None:
-            raise ValueError('the app must be run first to retrieve output data')
+            raise ValueError("the app must be run first to retrieve output data")
         return copy.copy(self._output_data)
 
     @property
     def export_extension(self):
         if self._output_data is None:
-            raise ValueError('the app must be run first to retrieve export file extension')
-        exporter = self._output_data['exporter']
+            raise ValueError(
+                "the app must be run first to retrieve export file extension"
+            )
+        exporter = self._output_data["exporter"]
         return exporter.file_extension
 
     @property
     def export_mimetype(self):
         if self._output_data is None:
-            raise ValueError('the app must be run first to retrieve export mimetype')
-        exporter = self._output_data['exporter']
+            raise ValueError("the app must be run first to retrieve export mimetype")
+        exporter = self._output_data["exporter"]
         return exporter.output_mimetype
 
     def assert_converted_exists(self, file_name=None, extension=None):
@@ -208,9 +208,9 @@ class IpyTestApp(object):
 
         converted_path = self.converted_path.joinpath(file_name + extension)
         if not self.converted_path.joinpath(file_name + extension).exists():
-            raise AssertionError('could not find: {}'.format(converted_path))
+            raise AssertionError("could not find: {}".format(converted_path))
 
-    def assert_converted_contains(self, regexes, encoding='utf8'):
+    def assert_converted_contains(self, regexes, encoding="utf8"):
 
         if self.input_file is None:
             file_name = self.source_path.name
@@ -228,9 +228,9 @@ class IpyTestApp(object):
         for regex in regexes:
 
             if not re.search(regex, content):
-                raise AssertionError('content does not contain regex: {}'.format(regex))
+                raise AssertionError("content does not contain regex: {}".format(regex))
 
-    def assert_converted_equals_expected(self, expected_file_name, encoding='utf8'):
+    def assert_converted_equals_expected(self, expected_file_name, encoding="utf8"):
 
         if self.input_file is None:
             file_name = self.source_path.name
@@ -242,21 +242,23 @@ class IpyTestApp(object):
         expected_path = self.expected_path.joinpath(expected_file_name + extension)
 
         mime_type = self.export_mimetype
-        if mime_type == 'text/latex':
+        if mime_type == "text/latex":
             compare_tex_files(converted_path, expected_path, encoding=encoding)
-        elif mime_type == 'text/html':
+        elif mime_type == "text/html":
             compare_html_files(converted_path, expected_path, encoding=encoding)
-        elif mime_type == 'text/restructuredtext':
+        elif mime_type == "text/restructuredtext":
             compare_rst_files(converted_path, expected_path, encoding=encoding)
         else:
             # TODO add comparison for nb (applicatio/json)
             # and python (application/x-python)
-            message = ('no comparison function exists for ' 'mimetype: {}'.format(mime_type))
+            message = "no comparison function exists for " "mimetype: {}".format(
+                mime_type
+            )
             # raise ValueError(message)
-            logger.warn(message)
+            logger.warning(message)
 
 
-def compare_rst_files(testpath, outpath, encoding='utf8'):
+def compare_rst_files(testpath, outpath, encoding="utf8"):
     # only compare body of html, since styles differ by
     # nbconvert/pandoc version (e.g. different versions of font-awesome)
 
@@ -267,7 +269,7 @@ def compare_rst_files(testpath, outpath, encoding='utf8'):
             content = fobj.read()
 
         # python 3.5 used .jpg instead of .jpeg
-        content = content.replace('.jpg', '.jpeg')
+        content = content.replace(".jpg", ".jpeg")
 
         # a recent dependency change is inserting new lines at the top of the file
         content = content.lstrip()
@@ -278,12 +280,20 @@ def compare_rst_files(testpath, outpath, encoding='utf8'):
 
     # only report differences
     if out_content != test_content:
-        raise AssertionError('\n' + '\n'.join(
-            context_diff(
-                test_content.splitlines(), out_content.splitlines(), fromfile=str(testpath), tofile=str(outpath))))
+        raise AssertionError(
+            "\n"
+            + "\n".join(
+                context_diff(
+                    test_content.splitlines(),
+                    out_content.splitlines(),
+                    fromfile=str(testpath),
+                    tofile=str(outpath),
+                )
+            )
+        )
 
 
-def compare_html_files(testpath, outpath, encoding='utf8'):
+def compare_html_files(testpath, outpath, encoding="utf8"):
     # only compare body of html, since styles differ by
     # nbconvert/pandoc version (e.g. different versions of font-awesome)
 
@@ -295,18 +305,18 @@ def compare_html_files(testpath, outpath, encoding='utf8'):
 
         # extract only the body
         # could use html.parser or beautifulsoup to do this better
-        body_rgx = re.compile('\\<body\\>(.*)\\</body\\>', re.DOTALL)
+        body_rgx = re.compile("\\<body\\>(.*)\\</body\\>", re.DOTALL)
         body_search = body_rgx.search(content)
         if not body_search:
-            raise IOError('could not find body content of {}'.format(path))
+            raise IOError("could not find body content of {}".format(path))
         content = body_search.group(1)
 
         # remove script environments which can change (e.g. reveal)
-        script_rgx = re.compile('\\<script\\>(.*)\\</script\\>', re.DOTALL)
-        content = script_rgx.sub('<script></script>', content)
+        script_rgx = re.compile("\\<script\\>(.*)\\</script\\>", re.DOTALL)
+        content = script_rgx.sub("<script></script>", content)
 
         # remove trailing whitespace
-        content = '\n'.join([l.rstrip() for l in content.splitlines()])
+        content = "\n".join([l.rstrip() for l in content.splitlines()])
 
         output.append(content)
 
@@ -314,12 +324,20 @@ def compare_html_files(testpath, outpath, encoding='utf8'):
 
     # only report differences
     if out_content != test_content:
-        raise AssertionError('\n' + '\n'.join(
-            context_diff(
-                test_content.splitlines(), out_content.splitlines(), fromfile=str(testpath), tofile=str(outpath))))
+        raise AssertionError(
+            "\n"
+            + "\n".join(
+                context_diff(
+                    test_content.splitlines(),
+                    out_content.splitlines(),
+                    fromfile=str(testpath),
+                    tofile=str(outpath),
+                )
+            )
+        )
 
 
-def compare_tex_files(testpath, outpath, encoding='utf8'):
+def compare_tex_files(testpath, outpath, encoding="utf8"):
 
     output = []
     for path in [testpath, outpath]:
@@ -330,35 +348,42 @@ def compare_tex_files(testpath, outpath, encoding='utf8'):
         # only certain versions of pandoc wrap sections with \hypertarget
         # NOTE a better way to do this might be to use TexSoup
         ht_rgx = re.compile(
-            '\\\\hypertarget\\{[^\\}]*\\}\\{[^\\\\]*'
-            '(\\\\[sub]*section\\{[^\\}]*\\}'
-            '\\\\label\\{[^\\}]*\\})'
-            '\\}', re.DOTALL)
-        content = ht_rgx.sub('\\g<1>', content)
+            "\\\\hypertarget\\{[^\\}]*\\}\\{[^\\\\]*"
+            "(\\\\[sub]*section\\{[^\\}]*\\}"
+            "\\\\label\\{[^\\}]*\\})"
+            "\\}",
+            re.DOTALL,
+        )
+        content = ht_rgx.sub("\\g<1>", content)
 
         # newer versions of pandoc convert ![](file) to \begin{figure}[htbp]
         # TODO override pandoc figure placement of ![](file) in markdown2latex
-        content = content.replace('\\begin{figure}[htbp]', '\\begin{figure}')
+        content = content.replace("\\begin{figure}[htbp]", "\\begin{figure}")
 
         # at start of itemize
-        content = content.replace('\\itemsep1pt\\parskip0pt\\parsep0pt\n', '')
+        content = content.replace("\\itemsep1pt\\parskip0pt\\parsep0pt\n", "")
         # at start of enumerate
-        content = content.replace('\\tightlist\n', '')
+        content = content.replace("\\tightlist\n", "")
 
         # python 3.5 used .jpg instead of .jpeg
-        content = content.replace('.jpg', '.jpeg')
+        content = content.replace(".jpg", ".jpeg")
 
         # python < 3.6 sorts these differently
-        pyg_rgx = re.compile(('\\\\expandafter\\\\def\\\\csname '
-                              'PY\\@tok\\@[0-9a-zA-Z]*\\\\endcsname[^\n]*'), re.MULTILINE)
-        content = pyg_rgx.sub(r'\<pygments definition\>', content)
+        pyg_rgx = re.compile(
+            (
+                "\\\\expandafter\\\\def\\\\csname "
+                "PY\\@tok\\@[0-9a-zA-Z]*\\\\endcsname[^\n]*"
+            ),
+            re.MULTILINE,
+        )
+        content = pyg_rgx.sub(r"\<pygments definition\>", content)
 
         # also remove all space from start of lines
-        space_rgx = re.compile(r'^[\s]*', re.MULTILINE)
-        content = space_rgx.sub('', content)
+        space_rgx = re.compile(r"^[\s]*", re.MULTILINE)
+        content = space_rgx.sub("", content)
 
         # remove trailing whitespace
-        content = '\n'.join([l.rstrip() for l in content.splitlines()])
+        content = "\n".join([l.rstrip() for l in content.splitlines()])
 
         output.append(content)
 
@@ -366,6 +391,14 @@ def compare_tex_files(testpath, outpath, encoding='utf8'):
 
     # only report differences
     if out_content != test_content:
-        raise AssertionError('\n' + '\n'.join(
-            context_diff(
-                test_content.splitlines(), out_content.splitlines(), fromfile=str(testpath), tofile=str(outpath))))
+        raise AssertionError(
+            "\n"
+            + "\n".join(
+                context_diff(
+                    test_content.splitlines(),
+                    out_content.splitlines(),
+                    fromfile=str(testpath),
+                    tofile=str(outpath),
+                )
+            )
+        )
